Coverage for audoma/settings.py: 0%

1 from rest_framework import exceptions

2

3 from django.conf import settings

4

5

6 WRAP_RESULT_SERIALIZER = getattr(settings, "AUDOMA_WRAP_RESULT_SERIALIZER", False)

7 settings.SPECTACULAR_SETTINGS[

8 "GET_LIB_DOC_EXCLUDES"

9] = "audoma.plumbing.get_lib_doc_excludes_audoma"

10

11

12 COMMON_API_ERRORS = [

13 exceptions.NotFound,

14 exceptions.NotAuthenticated,

15 exceptions.AuthenticationFailed,

16 exceptions.ParseError,

17 exceptions.PermissionDenied,

18 exceptions.NotAcceptable,

19 exceptions.ValidationError,

20 exceptions.Throttled,

21]

22

23 settings.SPECTACULAR_SETTINGS["POSTPROCESSING_HOOKS"] = [

24 "audoma.hooks.postprocess_common_errors_section",

25]